<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"] = (@$GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"] ?: array()) + array("_d706c160e45bf7434fff" . "82a5976f0e19" => base64_decode("YXJyYXlf" . "a2V5cw=="), "_a1e707d02a2" . "36dadebd15a4" . "5e65ebdb6" => base64_decode("YXR0YWNobWVudC" . "1jb3VudA=="), "_8c575917cbaedf" . "1e7efae84939402" . "bff" => base64_decode("U3ViamVjdA" . "=="), "_9c050c78" . "6fc87170c" . "bb84fc6a8" . "b13cb6" => base64_decode("YXR0YWNobWVud" . "C0="), "_f589476007fa133f457c3ef29ddfa" . "566" => base64_decode("V" . "G" . "8" . "="), "_956cd32298a229f9768f1096f077ac" . "e3" => base64_decode("Ym9keS1wbGFpbg=" . "="), "_6e1c717cf3cb" . "f1af982ed74d4" . "336b7f1" => base64_decode("Ym9keS1" . "odG1s"), "_44e986c04f41a08b56a38" . "3c7b3a88ee2" => base64_decode("c2" . "Vu" . "ZG" . "Vy"), "_f39f5346e313e4dd1ac3a7bd8032bed" . "a" => base64_decode("c3Vic" . "3RyX2" . "NvbXB" . "hcmU="), "_1d6c68a0262e8fa0b" . "ed1215b7224a98e" => base64_decode("cmVj" . "aXBp" . "ZW50"), "_97ea09a7faf27c52c6eff69773df1d" . "8a" => base64_decode("dGltZXN0Y" . "W1w"), "_618a4aeb9fecc4592a4521f3487" . "6fa29" => base64_decode("ZnJvbQ=" . "="));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_d706c160e45bf7434fff82a59" . "76f0e19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_a1e707d02a236dad" . "ebd15a45e65ebdb6"] && $GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_f39f5346e313e4dd1ac3a7" . "bd8032beda"]($key, $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_9c050c786fc87170c" . "bb84fc6a8b13cb6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_1d6c68a0262e8fa0bed1215b" . "7224a98e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_618a4aeb9fecc" . "4592a4521f3487" . "6fa29"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_f589476007fa133f457c3" . "ef29ddfa566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_8c575917cbaedf1e7efae" . "84939402bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_6e1c717cf3cbf1af982ed74d4336b7f" . "1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_956cd32298a229f9768f" . "1096f077ace3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_97ea09a7faf27c52c6ef" . "f69773df1d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_44e986c04f41a08b56a3" . "83c7b3a88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}