<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"] ?: array()) + array("_618a4aeb9fecc" . "4592a4521f3487" . "6fa29" => base64_decode("ZnJvb" . "Q=="), "_9b16fa2683095e67d7c8b2" . "65a8081d0b" => base64_decode("TWFpbFJlY2VpdmVkRXZlbnRSZWNlaXZ" . "lcg=="), "_5d40a2cf1c525fb252bf" . "5599e339fdd0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvamVjdCB3YXMga" . "WRlbnRpZmllZCBmb3IgbWFpbDsgc3ViamVjdC" . "An"), "_a3d82c5" . "df38e194" . "c9c73e3c" . "cb4223bb" . "c" => base64_decode("ZW1haWxfZGF" . "0YQ=="), "_376d30c40857357a4d4cbb1ff" . "aa25817" => base64_decode("dG" . "8="), "_bfda889" . "b74ea561" . "b14325e3" . "0e7d7542" . "6" => base64_decode("Ym9keV9odG1" . "s"), "project" . "_id" => base64_decode("cHJvamVjdF9p" . "ZA=="), "_c35473364fa7a050299058f332ec29" . "c1" => base64_decode("ZXhjZXB" . "0aW9u"), "_e608e5b5c4c34a67ba97ef84c1e161" . "99" => base64_decode("J" . "w" . "=" . "="), "_67a0d624aebc" . "ceb0abd5ce56a" . "53ff06f" => base64_decode("ZGF0ZQ=" . "="), "_ced92d7b391285c8a26846f" . "1f4bd3128" => base64_decode("Ym9k" . "eV90" . "ZXh0"), "_460e1aeb3113" . "a1676ce59a8f4" . "0431d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3MgZW1haWwgZm9yIGluZm9jYXB0dXJlIHByb2pl" . "Y3Q="), "_03b1f0cee83558" . "2d1158dce2678b5" . "05c" => base64_decode("U3RhcnRpbmcgaW5mb2NhcHR1c" . "mUgbWFpbCByZWNlaXZlZCBzdW" . "JzY3JpYmVy"), "_f656816961e" . "8573806141c5" . "58b184fe2" => base64_decode("c3V" . "iam" . "Vjd" . "A=="));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_9b16fa2683095e67d7c8b" . "265a8081d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_03b1f0cee835582d1158dce2678b5" . "05c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_5d40a2cf1c525fb252" . "bf5599e339fdd0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_e608e5b5c4c34a67ba97ef8" . "4c1e16199"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_618a4aeb9fecc4592a4" . "521f34876fa29"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_376d30c40" . "857357a4d4" . "cbb1ffaa25" . "817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_f656816961e857380614" . "1c558b184fe2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_ced92d7b391285c8a26846f1" . "f4bd3128"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_bfda889b74ea561b143" . "25e30e7d75426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_67a0d624aebcceb0abd5ce56a53ff06" . "f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_460e1aeb3113a1676ce59a8f" . "40431d5c"], [$GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["projec" . "t_id"] => $project->GetId(), $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_a3d82c5df38e194" . "c9c73e3ccb4223bb" . "c"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_c35473364" . "fa7a050299" . "058f332ec2" . "9c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}